@@ -1,5 +1,7 @@
 from newtools.optional_imports import boto3
 from newtools.aws import S3Location
+from newtools.doggo.doggo import FileDoggo
+import os
 
 
 class S3List:
@@ -94,16 +96,33 @@ class AthenaPartition:
             partitions_tracked += 1
         return partitions_list
 
-    def generate_sql(self, table, partitions_list, s3_path=None, ):
+    def generate_sql(self, table, partitions_list, s3_path=None, athena_client=None, output_location=None):
         """
                 :param table: The athena table partitions are being loaded for
                 :param partitions_list: The list of all the partitions to generate the alter table query for
                 :param s3_path: The prefix for where the data is stored, optional, can also be empty string to look at
                                 the toplevel of the bucket
+                :param athena_client: The current Athena Client, optional, will be used to list partitions already loaded
+                :param output_location: Output location of queries parsed into athena_client
                 :return: A list of queries that can be run to add all partitions
                 """
         s3_path = table if s3_path is None else s3_path
 
+        if athena_client is not None:
+            if output_location is None:
+                raise ValueError('output_location must be set to use athena_client')
+
+            query = athena_client.add_query("SHOW PARTITIONS {0}".format(table),
+                                            name="show_partitions_athena",
+                                            output_location=output_location)
+
+            athena_client.wait_for_completion()
+            fm = FileDoggo(os.path.join(query.arguments["output_location"], "{}.txt".format(query.id)), mode='rb', compression=None)
+            with fm as f:
+                athena_list = f.read().decode().splitlines()
+            athena_list = [{'Prefix': '{table}/{partition}/'.format(table=table, partition=partition)} for partition in athena_list]
+            partitions_list = [i for i in athena_list if i not in partitions_list]
+
         partition_string_list = []
         for i in partitions_list:
             partition_string = i.get('Prefix')
