@@ -57,8 +57,6 @@ from .sql_client import SqlClient
 from .athena import AthenaClient
 from newtools.doggo import DoggoLock, DoggoFileSystem, DynamoDogLock
 
-logger = logging.getLogger("newtools.cached_query")
-
 # Set S3fsMixin for backwards compatibility
 S3fsMixin = DoggoFileSystem
 
@@ -66,9 +64,10 @@ S3fsMixin = DoggoFileSystem
 class BaseCachedClass:
     validation_mode = False
 
-    def __init__(self, cache_path):
+    def __init__(self, cache_path, logger=logging.getLogger("newtools.cached_query") ):
         self.cache_path = cache_path
         self.dfs = DoggoFileSystem()
+        self._logger = logger
 
     def _exists(self, path):
         """
@@ -143,7 +142,7 @@ class BaseCachedQuery(BaseCachedClass):
     maximum_age = 3600
 
     def __init__(self, params=None, cache_path="", sql_archive_path=None, sql_paths=None, gzip=True,
-                 dynamodb_lock=True):
+                 dynamodb_lock=True, logger=logging.getLogger("newtools.cached_query")):
         """
         Cached query class
 
@@ -153,9 +152,11 @@ class BaseCachedQuery(BaseCachedClass):
         :param sql_paths: a list of paths to search for SQL queries
         :param gzip: if set, then results will be compression
         :param dynamodb_lock: defaults to True, using Dynamo DB for locking in S3
+        :param logger: the logger to use for this class and any newtools classes created by this class
         """
-        super().__init__(cache_path)
+        super().__init__(cache_path, logger)
 
+        self._logger = logger
         self._gzip = gzip
         self._args = self._validate_args(params)
 
@@ -171,14 +172,16 @@ class BaseCachedQuery(BaseCachedClass):
             return self._aws_lock(path,
                                   wait_period=self.wait_period,
                                   time_out_seconds=self.time_out_seconds,
-                                  maximum_age=self.maximum_age
+                                  maximum_age=self.maximum_age,
+                                  logger=self._logger
                                   )
         else:
             # short time outs for local file system
             return DoggoLock(path,
                              wait_period=self.wait_period,
                              time_out_seconds=self.time_out_seconds,
-                             maximum_age=self.maximum_age
+                             maximum_age=self.maximum_age,
+                             logger=self._logger
                              )
 
     def _validate_args(self, args):
@@ -260,7 +263,7 @@ class BaseCachedQuery(BaseCachedClass):
         if params is not None:
             clean = self._clean_dict(params)
             for param in clean:
-                logger.info("{0} = {1}".format(param, clean[param]))
+                self._logger.info("{0} = {1}".format(param, clean[param]))
 
     @staticmethod
     def __format_list(the_listl):
@@ -348,7 +351,7 @@ class BaseCachedQuery(BaseCachedClass):
                     for file in self.dfs.glob(output_file + "**"):
                         self.dfs.rm(file)
 
-                    logger.info("Executing query to {0}".format(output_file))
+                    self._logger.info("Executing query to {0}".format(output_file))
                     self._execute_query(query_file=file_path,
                                         output_file=output_file,
                                         query_parameters=query_parameters,
@@ -366,7 +369,7 @@ class BaseCachedQuery(BaseCachedClass):
                             else:
                                 self.dfs.mv(files[0], output_file)
 
-        logger.info("Loading query from {0}".format(output_file))
+        self._logger.info("Loading query from {0}".format(output_file))
         return output_file
 
     def _execute_query(self, **params):
@@ -406,8 +409,8 @@ class CachedPep249Query(BaseCachedQuery):
     __sql = None
 
     def __init__(self, pep_249_obj, params=None, cache_path="", sql_archive_path=None, sql_paths=None, gzip=True,
-                 dynamodb_lock=True):
-        super().__init__(params, cache_path, sql_archive_path, sql_paths, gzip, dynamodb_lock)
+                 dynamodb_lock=True, logger=logging.getLogger("newtools.cached_query")):
+        super().__init__(params, cache_path, sql_archive_path, sql_paths, gzip, dynamodb_lock, logger)
 
         self._sql = SqlClient(pep_249_obj,
                               logger=logger,
