@@ -14,10 +14,6 @@ from newtools.optional_imports import AWSRetry
 
 from newtools.aws import S3Location
 
-import logging
-
-logger = logging.getLogger("newtools.doggo")
-
 
 def _gzip_wrapped(func):
     def gzip_open(self, *args, **kwargs):
