@@ -3,8 +3,6 @@ import warnings
 import os
 import tempfile
 import shutil
-import logging
-from time import time
 
 from newtools.optional_imports import boto3
 from newtools.optional_imports import pandas as pd
